A country-year panel of the democracy index compiled by the Economist Intelligence Unit. Covers 2006, 2008, and 2010-2025 (EIU did not publish annual updates before 2010) for 167 countries.
The Economist Intelligence Unit. Democracy Index 2024: What's Wrong with Representative Democracy? Report. London, UK: The Economist Intelligence Unit Limited, 2025. https://www.eiu.com/n/global-themes/democracy-index/. The Economist Intelligence Unit. Democracy Index 2025: Democracy Stabilises after Eight Years of Decline. Report. London: Economist Intelligence Unit, 2026. https://www.eiu.com/n/campaigns/democracy-index-2025/..
The Economist Intelligence Unit. Democracy Index 2023: Age of Conflict. Report. London, United Kingdom: Economist Intelligence Unit, 2024..
Details
The 2025 EIU report is the first edition that does not include a country-by-country appendix of scores — EIU moved per-country data behind its paid Country Analysis / Snowflake services. From v0.7.0 onward this dataset is built from the Wikipedia aggregation at https://en.wikipedia.org/wiki/The_Economist_Democracy_Index, which was validated against the previously shipped PDF-derived snapshot (99.8% agreement for 2006-2024). A Niger / Nigeria swap for 2015 in the earlier version of this dataset is corrected here.
- eiu_country
Country name as in the original tables.
- eiu
Democracy index, ranging from 0 (least democratic) to to 10 (most democratic). The report says that the index "is based on five categories: electoral process and pluralism; civil liberties; the functioning of government; political participation; and political culture" which form "one interrelated whole".
Standard descriptive variables (generated by this package)
- extended_country_name
The name of the country in the Gleditsch-Ward system of states, or the official name of the entity (for non-sovereign entities and states not in the Gleditsch and Ward system of states) or else a common name for disputed cases that do not have an official name (e.g., Western Sahara, Hyderabad). The Gleditsch and Ward scheme sometimes indicates the common name of the country and (in parentheses) the name of an earlier incarnation of the state: thus, they have Germany (Prussia), Russia (Soviet Union), Madagascar (Malagasy), etc. For details, see Gleditsch, Kristian S. & Michael D. Ward. 1999. "Interstate System Membership: A Revised List of the Independent States since 1816." International Interactions 25: 393-413. The list can be found via the Wayback Machine at https://web.archive.org/web/20130627160240/http://privatewww.essex.ac.uk/~ksg/statelist.html.
- GWn
Gleditsch and Ward's numeric country code, from the Gleditsch and Ward list of independent states.
- cown
The Correlates of War numeric country code, 2016 version. This differs from Gleditsch and Ward's numeric country code in a few cases. See https://correlatesofwar.org/data-sets/state-system-membership/ for the full list.
- in_GW_system
Whether the state is "in system" (that is, is independent and sovereign), according to Gleditsch and Ward, for this particular date. Matches at the end of the year; so, for example South Vietnam 1975 is
FALSEbecause, according to Gleditsch and Ward, the country ended on April 1975 (being absorbed by North Vietnam). It is alsoTRUEfor dates beyond 2012 for countries that did not end by then, depsite the fact that the Gleditsch and Ward list has not been updated since.
See also
Other democracy:
LIED,
PIPE,
REIGN,
anckar,
anrr,
arat_pmm,
blm,
bmr,
bnr,
bollen_pmm,
bti,
doorenspleet,
download_fh(),
download_fh_electoral(),
download_fh_full(),
download_wgi_voice_and_accountability(),
extended_uds,
fh_pmm,
gwf_all,
hadenius_pmm,
kailitz,
magaloni,
mainwaring,
munck_pmm,
pacl,
pacl_update,
peps,
pitf,
polityIV,
polity_pmm,
polyarchy,
polyarchy_dimensions,
prc_gasiorowski,
svmdi,
svolik_regime,
uds_2014,
ulfelder,
utip,
vanhanen,
vaporeg,
vaporeg_2024,
vdem_simple,
wahman_teorell_hadenius,
wgi_legacy
Other continuous democracy indexes:
arat_pmm,
bollen_pmm,
bti,
download_wgi_voice_and_accountability(),
hadenius_pmm,
munck_pmm,
svmdi,
vanhanen,
vdem_simple,
wgi_legacy