The Varieties of Political Regimes (VaPoReg) dataset, legacy 2024 schema
Source:R/data_documentation.R
vaporeg_2024.Rdvaporeg_2024 preserves the pre-0.7.0 democracyData interface for VaPoReg.
It is the last packaged version of the old schema, covering 1900 to 2024 and
including the package's standardized country identifiers and derived
democracy measures. Use vaporeg for the current March 2026 edition.
S. Kailitz. Varieties of Political Regimes (va-PoReg). Codebook. Version 1.7. Tech. rep. Dresden: Hannah Arendt Institute for Totalitarianism Studies, 2024. S. Kailitz. Varieties of Political Regimes (va-PoReg). Dataset. Dresden, 2024.
Variables
- vaporeg_country
The name of the country or political unit for a given year.
- year
The calendar year.
- vaporeg_code
The VaPoReg unit identifier.
- GeoNamesID
Legacy geographic identifier for linking with spatial datasets.
- vaporeg_cowcode
The Correlates of War country code, where available.
- vaporeg_cr
Legacy compatibility alias of
vaporeg_s.- vaporeg_s
The standard classification of political regimes.
- vaporeg_a
An alternative classification that merges democracies and semi-democracies and groups monarchies together as ruling monarchies.
- vaporeg_governing_country
For colonial and occupation regimes, the ruling country.
- vaporeg_s_gc, vaporeg_a_gc
Standard and alternative regime classifications for the governing country.
- vaporeg_s_start, vaporeg_s_end, vaporeg_s_duration, vaporeg_s_change
Start date, end date, duration, and annual change indicator for the standard classification.
- vaporeg_a_start, vaporeg_a_end, vaporeg_a_duration, vaporeg_a_change
Start date, end date, duration, and annual change indicator for the alternative classification.
- Gapminder_pop, gm_world_pop
Population variables included in the legacy interface.
- un_region, un_continent
UN region and continent codes.
- extended_country_name, GWn, cown, in_GW_system
Standardized country identifiers added by
democracyData.- vaporeg_binary_strict
A dichotomous democracy indicator coded 1 only for the most demanding VaPoReg democracy category.
- vaporeg_binary_non_strict
A dichotomous democracy indicator coded 1 for both full and defective democracies.
- vaporeg_trichotomous
A trichotomous democracy indicator coded 2 for full democracy, 1 for defective democracy, and 0 otherwise.
Standard descriptive variables (generated by this package)
- extended_country_name
The name of the country in the Gleditsch-Ward system of states, or the official name of the entity (for non-sovereign entities and states not in the Gleditsch and Ward system of states) or else a common name for disputed cases that do not have an official name (e.g., Western Sahara, Hyderabad). The Gleditsch and Ward scheme sometimes indicates the common name of the country and (in parentheses) the name of an earlier incarnation of the state: thus, they have Germany (Prussia), Russia (Soviet Union), Madagascar (Malagasy), etc. For details, see Gleditsch, Kristian S. & Michael D. Ward. 1999. "Interstate System Membership: A Revised List of the Independent States since 1816." International Interactions 25: 393-413. The list can be found via the Wayback Machine at https://web.archive.org/web/20130627160240/http://privatewww.essex.ac.uk/~ksg/statelist.html.
- GWn
Gleditsch and Ward's numeric country code, from the Gleditsch and Ward list of independent states.
- cown
The Correlates of War numeric country code, 2016 version. This differs from Gleditsch and Ward's numeric country code in a few cases. See https://correlatesofwar.org/data-sets/state-system-membership/ for the full list.
- in_GW_system
Whether the state is "in system" (that is, is independent and sovereign), according to Gleditsch and Ward, for this particular date. Matches at the end of the year; so, for example South Vietnam 1975 is
FALSEbecause, according to Gleditsch and Ward, the country ended on April 1975 (being absorbed by North Vietnam). It is alsoTRUEfor dates beyond 2012 for countries that did not end by then, depsite the fact that the Gleditsch and Ward list has not been updated since.
See also
Other democracy:
LIED,
PIPE,
REIGN,
anckar,
anrr,
arat_pmm,
blm,
bmr,
bnr,
bollen_pmm,
bti,
doorenspleet,
download_fh(),
download_fh_electoral(),
download_fh_full(),
download_wgi_voice_and_accountability(),
eiu,
extended_uds,
fh_pmm,
gwf_all,
hadenius_pmm,
kailitz,
magaloni,
mainwaring,
munck_pmm,
pacl,
pacl_update,
peps,
pitf,
polityIV,
polity_pmm,
polyarchy,
polyarchy_dimensions,
prc_gasiorowski,
svmdi,
svolik_regime,
uds_2014,
ulfelder,
utip,
vanhanen,
vaporeg,
vdem_simple,
wahman_teorell_hadenius,
wgi_legacy
Other institutions:
LIED,
PIPE,
vaporeg
Other dichotomous democracy indexes:
anckar,
anrr,
bmr,
bnr,
doorenspleet,
kailitz,
pacl,
pacl_update,
svolik_regime,
ulfelder,
utip,
vaporeg,
wahman_teorell_hadenius
Other trichotomous democracy indexes:
blm,
kailitz,
mainwaring,
prc_gasiorowski,
utip,
vaporeg