Democracy, Voice, and Accountability Index from the World Governance Indicators, legacy series
Source:R/data_documentation.R
wgi_legacy.Rdwgi_legacy preserves the pre-0.7.0 democracyData version of the World
Governance Indicators "Voice and Accountability" index. It uses the
pre-2025 WGI methodology, covers 1996 to 2023, and is not directly
comparable to the revised wgi series introduced in 0.7.0.
D. Kaufmann and A. Kraay. Worldwide Governance Indicators. The World Bank Research Group, 2020. http://www.govindicators.org.
Details
The variable schema is identical to wgi; the descriptions below are unchanged from the earlier packaged release.
Variables
- wb_country
Country name (World Bank standard).
- wb_code
World bank 3 character country code.
- year
Year.
- Estimate
Estimate of governance (ranges from approximately -2.5 (weak) to 2.5 (strong) governance performance), with a mean of 0.
- StdErr
Standard error reflects variability around the point estimate of governance.
- NumSrc
Number of data sources on which estimate is based. The methodology document lists, among these, the EIU Democracy Index, Freedom House, the World Economic Forum Global Competitiveness Report, the Gallup World Poll, the Institutional Profiles Database, the Political Risk Services International Country Risk Guide, and Reporters Without Borders Press Freedom Index. See https://www.worldbank.org/content/dam/sites/govindicators/doc/va.pdf for more details.
- Rank
Percentile rank among all countries (ranges from 0 (lowest) to 100 (highest) rank).
- Lower
Lower bound of 90% confidence interval for governance, in percentile rank terms.
- Upper
Upper bound of 90% confidence interval for governance, in percentile rank terms.
Standard descriptive variables (generated by this package)
- extended_country_name
The name of the country in the Gleditsch-Ward system of states, or the official name of the entity (for non-sovereign entities and states not in the Gleditsch and Ward system of states) or else a common name for disputed cases that do not have an official name (e.g., Western Sahara, Hyderabad). The Gleditsch and Ward scheme sometimes indicates the common name of the country and (in parentheses) the name of an earlier incarnation of the state: thus, they have Germany (Prussia), Russia (Soviet Union), Madagascar (Malagasy), etc. For details, see Gleditsch, Kristian S. & Michael D. Ward. 1999. "Interstate System Membership: A Revised List of the Independent States since 1816." International Interactions 25: 393-413. The list can be found via the Wayback Machine at https://web.archive.org/web/20130627160240/http://privatewww.essex.ac.uk/~ksg/statelist.html.
- GWn
Gleditsch and Ward's numeric country code, from the Gleditsch and Ward list of independent states.
- cown
The Correlates of War numeric country code, 2016 version. This differs from Gleditsch and Ward's numeric country code in a few cases. See https://correlatesofwar.org/data-sets/state-system-membership/ for the full list.
- in_GW_system
Whether the state is "in system" (that is, is independent and sovereign), according to Gleditsch and Ward, for this particular date. Matches at the end of the year; so, for example South Vietnam 1975 is
FALSEbecause, according to Gleditsch and Ward, the country ended on April 1975 (being absorbed by North Vietnam). It is alsoTRUEfor dates beyond 2012 for countries that did not end by then, depsite the fact that the Gleditsch and Ward list has not been updated since.
See also
Other democracy:
LIED,
PIPE,
REIGN,
anckar,
anrr,
arat_pmm,
blm,
bmr,
bnr,
bollen_pmm,
bti,
doorenspleet,
download_fh(),
download_fh_electoral(),
download_fh_full(),
download_wgi_voice_and_accountability(),
eiu,
extended_uds,
fh_pmm,
gwf_all,
hadenius_pmm,
kailitz,
magaloni,
mainwaring,
munck_pmm,
pacl,
pacl_update,
peps,
pitf,
polityIV,
polity_pmm,
polyarchy,
polyarchy_dimensions,
prc_gasiorowski,
svmdi,
svolik_regime,
uds_2014,
ulfelder,
utip,
vanhanen,
vaporeg,
vaporeg_2024,
vdem_simple,
wahman_teorell_hadenius
Other continuous democracy indexes:
arat_pmm,
bollen_pmm,
bti,
download_wgi_voice_and_accountability(),
eiu,
hadenius_pmm,
munck_pmm,
svmdi,
vanhanen,
vdem_simple